.all-contributorsrc
.env
.env.test
.htaccess
AGENTS.md
CLAUDE.md
GEMINI.md
LICENSE.txt
MAINTAINERS.md
RELEASE_LEADS.md
SECURITY.md
app
autoload.php
bin
codeception.yml
composer.json
composer.lock
config
deleted_files.txt
ecs.php
favicon.ico
funding.json
index.php
media
package-lock.json
package.json
patches
phpstan-bootstrap.php
plugins
rector-older-symfony.php
rector-tests.php
robots.txt
templates
themes
translations
tsconfig.json
var
vendor
webpack.config.js