<?php

$your_webserver = strpos($_SERVER['SERVER_SOFTWARE'], 'LiteSpeed') !== false;

if(!empty($your_webserver)){
	echo '<soft_litespeed>soft_is_litespeed</soft_litespeed>';
}else{
	echo '<soft_litespeed>soft_is_not_litespeed</soft_litespeed>';	
}
	

?>