<?php
$parameters = array(
	'install_source' => 'Softaculous',
	'db_driver' => 'pdo_mysql',
	'db_host' => '[[softdbhost]]',
	'db_host_ro' => null,
	'db_table_prefix' => '[[dbprefix]]',
	'db_port' => '3306',
	'db_name' => '[[softdb]]',
	'db_user' => '[[softdbuser]]',
	'db_password' => '[[softdbpass]]',
	'db_backup_tables' => 1,
	'db_backup_prefix' => 'bak_',
	'db_server_version' => null,
	'secret_key' => '[[secret_key]]',
	'site_url' => '[[softurl]]',
	'locale' => '[[language]]',
);
